@@ -30,10 +30,6 @@
 #include <QLabel>
 #include <QTreeView>
 
-// KDE imports
-#include <KIcon>
-#include <KLocale>
-
 // KEduVocDocument
 #include <keduvoccontainer.h>
 #include <keduvocdocument.h>
@@ -100,13 +96,13 @@ void SummaryWordWidget::slotDocumentChanged(KEduVocDocument *doc)
 {
     m_doc = doc;
     if (!m_doc) {
-        kDebug() << "Set invalid document";
+        qDebug() << "Set invalid document";
         delete m_wordTypeModel;
         m_wordTypeModel = 0;
     } else {
         delete m_wordTypeView;
         if (!m_wordTypeModel) {
-            kDebug() << "Create word type model for summary view";
+            qDebug() << "Create word type model for summary view";
             m_wordTypeModel = new WordClassModel(this);
         }
         m_wordTypeModel->setDocument(m_doc);
@@ -161,7 +157,7 @@ void SummaryWordWidget::populateLessonList(KEduVocExpression *entry)
 void SummaryWordWidget::setCurrentWordType(KEduVocExpression *entry, int translation)
 {
     if (entry && entry->translation(translation)->wordType()) {
-        kDebug() << "Set current word type: " << entry->translation(translation)->wordType()->name();
+        qDebug() << "Set current word type: " << entry->translation(translation)->wordType()->name();
         // select the right word type
         m_wordTypeView->setCurrentIndex(m_wordTypeModel->index(entry->translation(translation)->wordType()));
     } else {
@@ -171,7 +167,7 @@ void SummaryWordWidget::setCurrentWordType(KEduVocExpression *entry, int transla
 
 void SummaryWordWidget::clear()
 {
-    kDebug() << "Clear summary widget";
+    qDebug() << "Clear summary widget";
 
     languageLabel->setText(QString());
     wordEntry->setText(QString());
@@ -206,7 +202,7 @@ void SummaryWordDelegate::setEditorData(QWidget *editor, const QModelIndex &inde
         case VocabularyModel::Example:
         case VocabularyModel::Paraphrase:
 
-            KLineEdit *entry = static_cast <KLineEdit *>(editor);
+            QLineEdit *entry = static_cast <QLineEdit *>(editor);
             if (entry) {
                 entry->setText(index.model()->data(index).toString());
             }
@@ -229,7 +225,3 @@ void SummaryWordWidget::wordTypeSelected(const QString& wordTypeName)
         }
     }
 }
-
-
-#include "summarywordwidget.moc"
-
