@@ -24,8 +24,8 @@
 
 #include <keduvocdocument.h>
 
-#include "configure-practice/configurepracticedialog.h"
-#include "lessonstatistics.h"
+#include "practice/configure/configurepracticedialog.h"
+#include "lessonstatisticsview.h"
 #include "statisticsmodel.h"
 #include "parleymainwindow.h"
 #include "parleyactions.h"
